@@ -4,6 +4,15 @@
 # This module is released under the MIT License:
 # http://www.opensource.org/licenses/mit-license.php
 
+import sys as _sys
+
+import six as _six
+
+
+def reraise(exception):
+    prev_cls, prev, tb = _sys.exc_info()
+    _six.reraise(type(exception), exception, tb)
+
 
 class Error(Exception):
 
